==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/ActionGroupsInformationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.ActionGroupsInformationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The Action Groups information, used by the alert rule.
 * @property customEmailSubject An optional custom email subject to use in email notifications.
 * @property customWebhookPayload An optional custom web-hook payload to use in web-hook notifications.
 * @property groupIds The Action Group resource IDs.
 */
public data class ActionGroupsInformationArgs(
    public val customEmailSubject: Output<String>? = null,
    public val customWebhookPayload: Output<String>? = null,
    public val groupIds: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.ActionGroupsInformationArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.ActionGroupsInformationArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.ActionGroupsInformationArgs.builder()
            .customEmailSubject(customEmailSubject?.applyValue({ args0 -> args0 }))
            .customWebhookPayload(customWebhookPayload?.applyValue({ args0 -> args0 }))
            .groupIds(groupIds.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ActionGroupsInformationArgs].
 */
@PulumiTagMarker
public class ActionGroupsInformationArgsBuilder internal constructor() {
    private var customEmailSubject: Output<String>? = null

    private var customWebhookPayload: Output<String>? = null

    private var groupIds: Output<List<String>>? = null

    /**
     * @param value An optional custom email subject to use in email notifications.
     */
    @JvmName("vmvuhpbwdnqdyifp")
    public suspend fun customEmailSubject(`value`: Output<String>) {
        this.customEmailSubject = value
    }

    /**
     * @param value An optional custom web-hook payload to use in web-hook notifications.
     */
    @JvmName("oyiffdjutwwqswmm")
    public suspend fun customWebhookPayload(`value`: Output<String>) {
        this.customWebhookPayload = value
    }

    /**
     * @param value The Action Group resource IDs.
     */
    @JvmName("dxsorimexfuqdtbe")
    public suspend fun groupIds(`value`: Output<List<String>>) {
        this.groupIds = value
    }

    @JvmName("ypcrbyuofifyduis")
    public suspend fun groupIds(vararg values: Output<String>) {
        this.groupIds = Output.all(values.asList())
    }

    /**
     * @param values The Action Group resource IDs.
     */
    @JvmName("rurminwwokstuhas")
    public suspend fun groupIds(values: List<Output<String>>) {
        this.groupIds = Output.all(values)
    }

    /**
     * @param value An optional custom email subject to use in email notifications.
     */
    @JvmName("qtpbgepupnxjxccf")
    public suspend fun customEmailSubject(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customEmailSubject = mapped
    }

    /**
     * @param value An optional custom web-hook payload to use in web-hook notifications.
     */
    @JvmName("mxcunkcnhehaagih")
    public suspend fun customWebhookPayload(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customWebhookPayload = mapped
    }

    /**
     * @param value The Action Group resource IDs.
     */
    @JvmName("uqvcdyxhtlkoquau")
    public suspend fun groupIds(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groupIds = mapped
    }

    /**
     * @param values The Action Group resource IDs.
     */
    @JvmName("xsbxavuixtvhgreu")
    public suspend fun groupIds(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groupIds = mapped
    }

    internal fun build(): ActionGroupsInformationArgs = ActionGroupsInformationArgs(
        customEmailSubject = customEmailSubject,
        customWebhookPayload = customWebhookPayload,
        groupIds = groupIds ?: throw PulumiNullFieldException("groupIds"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/alertsmanagement/kotlin/inputs/ActionGroupsInformationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.alertsmanagement.kotlin.inputs

import com.pulumi.azurenative.alertsmanagement.inputs.ActionGroupsInformationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The Action Groups information, used by the alert rule.
 * @property customEmailSubject An optional custom email subject to use in email notifications.
 * @property customWebhookPayload An optional custom web-hook payload to use in web-hook notifications.
 * @property groupIds The Action Group resource IDs.
 */
public data class ActionGroupsInformationArgs(
    public val customEmailSubject: Output<String>? = null,
    public val customWebhookPayload: Output<String>? = null,
    public val groupIds: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.azurenative.alertsmanagement.inputs.ActionGroupsInformationArgs> {
    override fun toJava(): com.pulumi.azurenative.alertsmanagement.inputs.ActionGroupsInformationArgs =
        com.pulumi.azurenative.alertsmanagement.inputs.ActionGroupsInformationArgs.builder()
            .customEmailSubject(customEmailSubject?.applyValue({ args0 -> args0 }))
            .customWebhookPayload(customWebhookPayload?.applyValue({ args0 -> args0 }))
            .groupIds(groupIds.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ActionGroupsInformationArgs].
 */
@PulumiTagMarker
public class ActionGroupsInformationArgsBuilder internal constructor() {
    private var customEmailSubject: Output<String>? = null

    private var customWebhookPayload: Output<String>? = null

    private var groupIds: Output<List<String>>? = null

    /**
     * @param value An optional custom email subject to use in email notifications.
     */
    @JvmName("lijqccnobofavcjg")
    public suspend fun customEmailSubject(`value`: Output<String>) {
        this.customEmailSubject = value
    }

    /**
     * @param value An optional custom web-hook payload to use in web-hook notifications.
     */
    @JvmName("dtsntnxyaefsgbfs")
    public suspend fun customWebhookPayload(`value`: Output<String>) {
        this.customWebhookPayload = value
    }

    /**
     * @param value The Action Group resource IDs.
     */
    @JvmName("emtkswupjflalfxe")
    public suspend fun groupIds(`value`: Output<List<String>>) {
        this.groupIds = value
    }

    @JvmName("gxcemjrchskgirng")
    public suspend fun groupIds(vararg values: Output<String>) {
        this.groupIds = Output.all(values.asList())
    }

    /**
     * @param values The Action Group resource IDs.
     */
    @JvmName("cjqimxnhmbcqrgnp")
    public suspend fun groupIds(values: List<Output<String>>) {
        this.groupIds = Output.all(values)
    }

    /**
     * @param value An optional custom email subject to use in email notifications.
     */
    @JvmName("sdcqkqljfcxiecvi")
    public suspend fun customEmailSubject(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customEmailSubject = mapped
    }

    /**
     * @param value An optional custom web-hook payload to use in web-hook notifications.
     */
    @JvmName("wabskpudwlhcdhrh")
    public suspend fun customWebhookPayload(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customWebhookPayload = mapped
    }

    /**
     * @param value The Action Group resource IDs.
     */
    @JvmName("klkqbcgdatrtfbxf")
    public suspend fun groupIds(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groupIds = mapped
    }

    /**
     * @param values The Action Group resource IDs.
     */
    @JvmName("wgfgcxoxlpilorcq")
    public suspend fun groupIds(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.groupIds = mapped
    }

    internal fun build(): ActionGroupsInformationArgs = ActionGroupsInformationArgs(
        customEmailSubject = customEmailSubject,
        customWebhookPayload = customWebhookPayload,
        groupIds = groupIds ?: throw PulumiNullFieldException("groupIds"),
    )
}
